@@ -5,6 +5,7 @@
 def get_class(module_name, klass):
     module = __import__(module_name)
     if '.' in module_name:
-        module = reduce(getattr, module_name.split('.')[1:], module)
+        for part in module_name.split('.')[1:]:
+            module = getattr(module, part)
 
     return getattr(module, klass)
